@@ -12,7 +12,7 @@ test_that("[ method for SBS96Catalog", {
                            file = file.path(tempdir(), "test.pdf"))
   expect_equal(out1$plot.success, TRUE)
   expect_equal(out2$plot.success, TRUE)
-  expect_error(PlotCatalog(catalog.counts[, 1]))
+  PlotCatalog(catalog.counts[, 1])
   graphics.off()
   unlink(file.path(tempdir(), "test.pdf"))
 })
@@ -30,7 +30,7 @@ test_that("[ method for SBS192Catalog", {
                            file = file.path(tempdir(), "test.pdf"))
   expect_equal(out1$plot.success, TRUE)
   expect_equal(out2$plot.success, TRUE)
-  expect_error(PlotCatalog(catalog.counts[, 1]))
+  PlotCatalog(catalog.counts[, 1])
   graphics.off()
   unlink(file.path(tempdir(), "test.pdf"))
 })
@@ -47,7 +47,7 @@ test_that("[ method for SBS1536Catalog", {
                            file = file.path(tempdir(), "test.pdf"))
   expect_equal(out1$plot.success, TRUE)
   expect_equal(out2$plot.success, TRUE)
-  expect_error(PlotCatalog(catalog.counts[, 1]))
+  PlotCatalog(catalog.counts[, 1])
   graphics.off()
   unlink(file.path(tempdir(), "test.pdf"))
 })
@@ -64,7 +64,7 @@ test_that("[ method for DBS78Catalog", {
                            file = file.path(tempdir(), "test.pdf"))
   expect_equal(out1$plot.success, TRUE)
   expect_equal(out2$plot.success, TRUE)
-  expect_error(PlotCatalog(catalog.counts[, 1]))
+  PlotCatalog(catalog.counts[, 1])
   graphics.off()
   unlink(file.path(tempdir(), "test.pdf"))
 })
@@ -82,7 +82,7 @@ test_that("[ method for DBS144Catalog", {
                            file = file.path(tempdir(), "test.pdf"))
   expect_equal(out1$plot.success, TRUE)
   expect_equal(out2$plot.success, TRUE)
-  expect_error(PlotCatalog(catalog.counts[, 1]))
+  PlotCatalog(catalog.counts[, 1])
   graphics.off()
   unlink(file.path(tempdir(), "test.pdf"))
 })
@@ -99,7 +99,7 @@ test_that("[ method for DBS136Catalog", {
                            file = file.path(tempdir(), "test.pdf"))
   expect_equal(out1$plot.success, TRUE)
   expect_equal(out2$plot.success, TRUE)
-  expect_error(PlotCatalog(catalog.counts[, 1]))
+  PlotCatalog(catalog.counts[, 1])
   graphics.off()
   unlink(file.path(tempdir(), "test.pdf"))
 })
@@ -115,7 +115,7 @@ test_that("[ method for IndelCatalog", {
                            file = file.path(tempdir(), "test.pdf"))
   expect_equal(out1$plot.success, TRUE)
   expect_equal(out2$plot.success, TRUE)
-  expect_error(PlotCatalog(catalog.counts[, 1]))
+  PlotCatalog(catalog.counts[, 1])
   graphics.off()
   unlink(file.path(tempdir(), "test.pdf"))
   unlink("Rplots.pdf")
